@@ -13,7 +13,7 @@
 #include <qstyle.h>
 
 KDEsuDialog::KDEsuDialog(QByteArray user, QByteArray authUser, bool enableKeep, const QString& icon, bool withIgnoreButton)
-    : KPasswordDialog(0, enableKeep ? ShowKeepPassword : NoFlags)
+    : KPasswordDialog(nullptr, enableKeep ? ShowKeepPassword : NoFlags)
 {
     if ( !icon.isEmpty() ) {
         setPixmap(QIcon::fromTheme(icon).pixmap(style()->pixelMetric(QStyle::PM_LargeIconSize)));
